@@ -26,13 +26,13 @@ from apis_core.default_settings.RDF_settings_new import sameAs
 APIS_RDF_YAML_SETTINGS = getattr(
         settings,
         'APIS_RDF_YAML_SETTINGS',
-        os.path.join(settings.BASE_DIR, 'apis_core', 'default_settings', 'RDF_default_settings.yml')
+        os.path.join(os.path.dirname(__file__), '../default_settings', 'RDF_default_settings.yml')
     )
 
 APIS_RDF_URI_SETTINGS = getattr(
         settings,
         'APIS_RDF_URI_SETTINGS',
-        os.path.join(settings.BASE_DIR, 'apis_core', 'default_settings', "URI_replace_settings.yml")
+        os.path.join(os.path.dirname(__file__), '../default_settings', "URI_replace_settings.yml")
     )
 
 
